
import '../wrappers/aidlab_synchronization_wrapper.dart';
import '../wrappers/platform_aidlab_sdk.dart';

import 'aidlab_synchronization_delegate.dart';
import 'ecg_filtration_method.dart';

class Aidlab {

  final PlatformAidlab _platformAidlab;

  final String firmwareRevision;
  final String hardwareRevision;
  final String serialNumber;

  set aidlabSynchronizationDelegate(AidlabSynchronizationDelegate delegate) {
    AidlabSynchronizationWrapper.listen(delegate, this);
  }

  Aidlab(this.firmwareRevision, this.hardwareRevision, this.serialNumber) :
        _platformAidlab = PlatformAidlab();

  void disconnect() {
    _platformAidlab.disconnect();
  }

  void send(String command) {
    _platformAidlab.send(
        SendRequest()
          ..command = command
    );
  }

  void setEcgFiltrationMethod(EcgFiltrationMethod ecgFiltrationMethod) {
    _platformAidlab.setECGFiltrationMethod(
        EcgFiltrationRequest()
          ..method = ecgFiltrationMethod.value
    );
  }

  void startSynchronization() {
    _platformAidlab.startSynchronization();
  }

  void stopSynchronization() {
    _platformAidlab.stopSynchronization();
  }

  void requestForFirmwareInfo(String url) {
    _platformAidlab.requestForFirmwareInfo(
        FirmwareInfoRequest()
          ..url = url
    );
  }

  void startFirmwareUpdate(String url, String updatableVersion) {
    _platformAidlab.startFirmwareUpdate(
        FirmwareUpdateRequest()
          ..url = url
          ..updatableVersion = updatableVersion
    );
  }

}
